@@ -141,11 +141,10 @@ class SyncClientProtocol(JSONCommandProtocol):
             self._client.setRoom(roomName)
         self.logged = True
         if self.persistentRoomWarning(featureList):
-            if len(motd) > 0:
-                motd += "\n\n"
-            motd += getMessage("persistent-rooms-notice")
+            span = "\n\n" if motd else ""
+            motd = getMessage("persistent-rooms-notice") + span + motd
         if motd:
-            self._client.ui.showMessage(motd, True, True)
+            self._client.ui.showMessage(motd, noPlayer=True, noTimestamp=True, isMotd=True)
         self._client.ui.showMessage(getMessage("connected-successful-notification"))
         self._client.connected()
         self._client.sendFile()
@@ -397,7 +396,18 @@ class SyncClientProtocol(JSONCommandProtocol):
 
     def handshakeCompleted(self):
         self._serverCertificateTLS = self.transport.getPeerCertificate()
-        self._subjectTLS = self._serverCertificateTLS.get_subject().CN
+        if not self._serverCertificateTLS:
+            self._client.ui.showErrorMessage(getMessage("startTLS-server-certificate-invalid"))
+            self.sendHello()
+            return
+
+        for x in range(0,self._serverCertificateTLS.get_extension_count()):
+            if (self._serverCertificateTLS.get_extension(x).get_short_name() == b'subjectAltName'):
+                self._subjectTLS = self._serverCertificateTLS.get_extension(x).__str__().replace("DNS:", "")
+
+        if not self._subjectTLS:
+            self._subjectTLS = self._client._config.get("host", "") or ""
+
         self._issuerTLS = self._serverCertificateTLS.get_issuer().CN
         self._expiredTLS =self._serverCertificateTLS.has_expired()
         self._expireDateTLS = datetime.strptime(self._serverCertificateTLS.get_notAfter().decode('ascii'), '%Y%m%d%H%M%SZ')
@@ -556,9 +566,8 @@ class SyncServerProtocol(JSONCommandProtocol):
         hello["features"] = self._factory.getFeatures()
         hello["motd"] = self._factory.getMotd(userIp, username, room, clientVersion)
         if self.persistentRoomWarning(clientFeatures=self._features, serverFeatures=hello["features"]):
-            if len(hello["motd"]) > 0:
-                hello["motd"] += "\n\n"
-            hello["motd"] += getMessage("persistent-rooms-notice")
+            span = "\n\n" if hello["motd"] else ""
+            hello["motd"] = getMessage("persistent-rooms-notice") + span + hello["motd"]
         self.sendMessage({"Hello": hello})
 
     @requireLogged
